multiSelect property
When true (default) multiple items can be selected simultaneously.
When false only one item can be active at a time – selecting a new
item deselects the previous one and closes the sheet automatically.
Implementation
final bool multiSelect;