CodeCountryPhone class

Constructors

CodeCountryPhone({required String phoneCode, required String flag, required String name, required String codeValue, required String localName, bool enableShortcutsThousands = true, String symbol = "\$"})

Properties

codeValue String
final
enableShortcutsThousands bool
final
flag String
final
hashCode int
The hash code for this object.
no setterinherited
localName String
final
name String
final
phoneCode String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited